@@ -1,7 +1,11 @@
-# This is file ../spam/R/tcrossprod.R
-# This file is part of the spam package, 
-#      http://www.math.uzh.ch/furrer/software/spam/
-# by Reinhard Furrer [aut, cre], Florian Gerber [ctb]
+# HEADER ####################################################
+# This is file  spam/R/tcrossprod.R.                        #
+# This file is part of the spam package,                    #
+#      http://www.math.uzh.ch/furrer/software/spam/         #
+# by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
+#    Daniel Gerber [ctb], Kaspar Moesinger [ctb]            #
+# HEADER END ################################################
+
      
 
 crossprod.spam <- function(x, y=NULL) {
@@ -11,11 +15,11 @@ crossprod.spam <- function(x, y=NULL) {
 
         if(dimx[2]==1L) return(matrix( sum(x@entries^2)))
 
-        return( .spam.matmul(t.spam(x),x))
+        return( t.spam(x) %*% x)
     }
     if( (!is.spam(x)) & (!is.spam(y))) return(crossprod(x,y))
     
-    return( .spam.matmul(t(x),y))
+    return( t(x) %*% y)
     
 }
 tcrossprod.spam <- function(x, y=NULL) {
@@ -25,16 +29,20 @@ tcrossprod.spam <- function(x, y=NULL) {
 
         if(dimx[2]==1L) return(matrix( sum(x@entries^2)))
 
-        return( .spam.matmul(x,t.spam(x)))
+        return( x %*% t.spam(x))
     }
     if( (!is.spam(x)) & (!is.spam(y))) return(tcrossprod(x,y))
     
-    return( .spam.matmul(x,t(y)))
+    return( x %*% t(y))
     
 }
 
 
 setMethod("crossprod",signature(x="spam",y="missing"), crossprod.spam)
+setMethod("crossprod",signature(x="spam",y="spam"), crossprod.spam)
+setMethod("crossprod",signature(x="spam",y="ANY"), crossprod.spam)
 setMethod("crossprod",signature(x="ANY",y="spam"), crossprod.spam)
 setMethod("tcrossprod",signature(x="spam",y="missing"), tcrossprod.spam)
+setMethod("tcrossprod",signature(x="spam",y="spam"), tcrossprod.spam)
+setMethod("tcrossprod",signature(x="spam",y="ANY"), tcrossprod.spam)
 setMethod("tcrossprod",signature(x="ANY",y="spam"), tcrossprod.spam)
