@@ -6,7 +6,24 @@
 
 
 # INITALIZE AND FUNCTIONS:
-require( fields, warn.conflict=FALSE)
+# JSS article:
+#     "spam: A Sparse Matrix R Package with Emphasis on
+#            MCMC Methods for Gaussian Markov Random Fields"
+
+
+# Compared to the R code in the article, here we give:
+# - improved formatting
+# - more comments, e.g. how to run the code using regular matrices 
+# - the code to construct the figures
+# - minor modifcations due to evolvement of spam
+ 
+
+cat("\nThis demo contains the R code of the second example\nin the JSS article. As pointed out by Steve Geinitz\nand Andrea Riebler, the Gibbs sampler is not correct\nand contains several bugs. \n\nI'll post an updated sampler in a future release.\n\n") 
+
+
+# INITALIZE AND FUNCTIONS:
+require("fields", warn.conflict=FALSE)
+options(spam.structurebased=TRUE)
 
 
 # READ DATA:
@@ -29,7 +46,7 @@ set.seed(14)
 # (based on unit precision parameters kappa, denoted with k):
 
 Q1 <- R <- diag.spam( diff(A@rowpointers)) - A   # this is R in (2)
-dim(Q1) <- c(2*n,2*n)
+pad(Q1) <- c(2*n,2*n)  # previously:  dim(Q1) <- c(2*n,2*n)
 
 Q2 <-  rbind(cbind( diag.spam(n), -diag.spam(n)),
        	     cbind(-diag.spam(n),  diag.spam(n)))
@@ -71,7 +88,7 @@ postshape <- ahyper + c(n-1,n)/2
 
 accept <- numeric(totalg)
 
-struct <- chol(Q1 + Q2 + diagC,
+struct <- chol(Q1 + Q2 + diag.spam(2*n),
                memory=list(nnzcolindices=5500))
 
 # struct <- NULL        # If no update steps are wanted
@@ -143,7 +160,7 @@ if (FALSE) {
 # POSTPROCESSING:
 
 accept <- accept[-c(1:burnin)]
-cat('\nAcceptance rate:',mean(accept),'\n')
+cat("\nAcceptance rate:",mean(accept),"\n")
 
 kpost <- kpost[-c(1:burnin),]
 upost <- upost[-c(1:burnin),]
@@ -160,6 +177,7 @@ npostmedian <- apply(npost,2,median)
 vpost <- npost-upost
 vpostmedian <- apply(vpost,2,median)
 
+
 #
 
 
@@ -175,22 +193,22 @@ map.landkreis(exp(upostmedian),zlim=c(.1,2.4))
 
 
 par(mfcol=c(2,4),mai=c(.5,.5,.05,.1),mgp=c(2.3,.8,0))
-hist(kpost[,1],main='',xlab=expression(kappa[u]),prob=T)
+hist(kpost[,1],main="",xlab=expression(kappa[u]),prob=TRUE)
 lines(density(kpost[,1]),col=2)
 tmp <- seq(0,to=max(kpost[,1]),l=500)
 lines(tmp,dgamma(tmp,ahyper[1],bhyper[1]),col=4)
 abline(v=kpostmedian[1],col=3)
 
-hist(kpost[,2],main='',xlab=expression(kappa[y]),prob=T)
+hist(kpost[,2],main="",xlab=expression(kappa[y]),prob=TRUE)
 lines(density(kpost[,2]),col=2)
 tmp <- seq(0,to=max(kpost[,2]),l=500)
 lines(tmp,dgamma(tmp,ahyper[2],bhyper[2]),col=4)
 abline(v=kpostmedian[2],col=3)
 
 # Trace plots:
-plot(kpost[,1],ylab=expression(kappa[u]),type='l')
+plot(kpost[,1],ylab=expression(kappa[u]),type="l")
 abline(h=kpostmedian[1],col=3)
-plot(kpost[,2],ylab=expression(kappa[y]),type='l')
+plot(kpost[,2],ylab=expression(kappa[y]),type="l")
 abline(h=kpostmedian[2],col=3)
 
 # ACF:
@@ -204,10 +222,9 @@ plot(kpost[,1],kpost[,2],xlab=expression(kappa[u]),ylab=expression(kappa[y]))
 abline(v=kpostmedian[1],h=kpostmedian[2],col=3)
 
 
-plot(accept+rnorm(ngibbs,sd=.05),pch='.',ylim=c(-1,2),yaxt='n',ylab='')
-text(ngibbs/2,1/2,paste('Acceptance rate:',round(mean(accept),3)))
-axis(2,at=c(0,1),label=c('Reject','Accept'))
-
+plot(accept+rnorm(ngibbs,sd=.05),pch=".",ylim=c(-1,2),yaxt="n",ylab="")
+text(ngibbs/2,1/2,paste("Acceptance rate:",round(mean(accept),3)))
+axis(2,at=c(0,1),label=c("Reject","Accept"))
 
 }
 
